@@ -159,3 +159,10 @@ class ExtendedImageField(ImageField):
             image = getattr(kwargs['instance'], self.attname)
             image.delete_previews()
             image.delete_file()
+
+
+try:
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], [r'^eif\.fields\.ExtendedImageField'])
+except ImportError:
+    pass
