@@ -11,12 +11,12 @@ class ExtendedImageWidget(FileInput):
         if not self.attrs is None:
             preview_name = self.attrs['preview']
             if preview_name == 'self' and hasattr(value, 'url'):
-                output.append(('<a target="_blank" href="%s">'
+                output.append(('<br /><br /><a target="_blank" href="%s">'
                            '<img src="%s" style="height: %dpx; width=%dpx;" /></a><br /> '
                            % (value.url, value.url, value.height, value.width)))
             elif value and hasattr(value, preview_name):
                 preview = getattr(value, preview_name)
-                output.append(('<a target="_blank" href="%s">'
+                output.append(('<br /><br /><a target="_blank" href="%s">'
                            '<img src="%s" style="height: %dpx; width=%dpx;" /></a><br /> '
                            % (value.url, preview['url'], preview['height'], preview['width'])))
         output.append(super(ExtendedImageWidget, self).render(name, value, attrs))
